package pro.devonics.flutter.flutter_push_devonics;

import android.app.Activity;
import android.content.Context;
import android.util.Log;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import pro.devonics.push.PushDevonics;

/** FlutterPushDevonicsPlugin */
public class FlutterPushDevonicsPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private PushDevonics pushDevonics;
  private Context context;
  private Activity activity;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_push_devonics");
    channel.setMethodCallHandler(this);
    context = flutterPluginBinding.getApplicationContext();
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("init")) {
      String appId = call.argument("app_id");
      if (appId != null) {
        Log.d("Push Devonics Init - ", appId);
        pushDevonics = new PushDevonics(context, appId);
        String internalId = pushDevonics.getInternalId();
        if (internalId != null) {
          pushDevonics.startSession();
          pushDevonics.sendIntent(activity.getIntent());
        } else {

        }
      } else {
        Log.d("Push Devonics Init Error - ", "Empty App ID");
      }
    } else if (call.method.equals("sendTag")) {
      String key = call.argument("key");
      String value = call.argument("value");
      if (key != null && value != null) {
        pushDevonics.setTags(key, value);
        Log.d("Push Devonics Send Tag Ok - ", key + " - " + value);
      } else {
        Log.d("Push Devonics Send Tag Error - ", "Empty Key Or Value");
      }
    } else if (call.method.equals("getUserID")) {
        String internalId = pushDevonics.getInternalId();
        result.success(internalId);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
      activity = binding.getActivity();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
    activity = binding.getActivity();
    pushDevonics.startSession();
    pushDevonics.sendIntent(activity.getIntent());
  }

  @Override
  public void onDetachedFromActivity() {
    pushDevonics.stopSession();
  }
}
